@@ -1,7 +1,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2024. All Rights Reserved.
+%% Copyright Ericsson AB 1996-2026. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -1909,7 +1909,12 @@ update_fun_name_1([Tok|Toks], L, FA, St) ->
 		    update_fun_name_1(Toks, L, FA, St)
 	    end;
 	left ->
-	    update_fun_name_1(Toks, L+1, FA, St);
+            case FA of
+                {Name,0} ->
+                    update_fun_name_1(Toks, L+1, {Name,1}, St);
+                {_,_} ->
+                    update_fun_name_1(Toks, L+1, FA, St)
+            end;
 	right when L =:= 1 ->
 	    FA;
 	right ->
